@@ -1,7 +1,7 @@
 package App::ListOrgHeadlines;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2016-04-30'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use strict;
@@ -226,8 +226,23 @@ _
             description => <<'_',
 
 If set to true, instead of returning a list, this function will return a hash of
-lists, keyed by tag: {tag1: [hl1, hl2, ...], tag2: [...]}. Note that some
-headlines might be listed more than once if it has several tags.
+lists, keyed by tag: {tag1: [hl1, hl2, ...], tag2: [...]}. Note that a headline
+that has several tags will only be listed under its first tag, unless when
+`allow_duplicates` is set to true, in which case the headline will be listed
+under each of its tag.
+
+_
+            tags => ['format'],
+        },
+        allow_duplicates => {
+            schema => ['bool'],
+            summary => 'Whether to allow headline to be listed more than once',
+            description => <<'_',
+
+This is only relevant when `group_by_tags` is on. Normally when a headline has
+several tags, it will only be listed under its first tag. But when this option
+is turned on, the headline will be listed under each of its tag (which mean a
+single headline will be listed several times).
 
 _
             tags => ['format'],
@@ -361,6 +376,8 @@ sub list_org_headlines {
 
     my $res;
     if ($args{group_by_tags}) {
+        my %seen;
+
         # cache tags in each @res element's [3] element
         for (@res) { $_->[3] = [$_->[2]->get_tags] }
         my @tags = sort(uniq(map {@{$_->[3]}} @res));
@@ -373,6 +390,7 @@ sub list_org_headlines {
                 } else {
                     next unless $tag ~~ @{$_->[3]};
                 }
+                next if !$args{allow_duplicates} && $seen{$_->[0]}++;
                 push @{ $res->{$tag} }, $_->[0];
             }
         }
@@ -398,7 +416,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.41 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2016-04-01.
+This document describes version 0.42 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2016-04-30.
 
 =head1 SYNOPSIS
 
@@ -419,6 +437,15 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<allow_duplicates> => I<bool>
+
+Whether to allow headline to be listed more than once.
+
+This is only relevant when C<group_by_tags> is on. Normally when a headline has
+several tags, it will only be listed under its first tag. But when this option
+is turned on, the headline will be listed under each of its tag (which mean a
+single headline will be listed several times).
+
 =item * B<detail> => I<bool> (default: 0)
 
 Show details instead of just titles.
@@ -453,8 +480,10 @@ Only show headlines having this level as the minimum.
 Whether to group result by tags.
 
 If set to true, instead of returning a list, this function will return a hash of
-lists, keyed by tag: {tag1: [hl1, hl2, ...], tag2: [...]}. Note that some
-headlines might be listed more than once if it has several tags.
+lists, keyed by tag: {tag1: [hl1, hl2, ...], tag2: [...]}. Note that a headline
+that has several tags will only be listed under its first tag, unless when
+C<allow_duplicates> is set to true, in which case the headline will be listed
+under each of its tag.
 
 =item * B<has_tags> => I<array[str]>
 
@@ -547,7 +576,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
 
 =head1 BUGS
 
