@@ -1,7 +1,7 @@
 package App::ListOrgTodos;
 
-our $DATE = '2016-04-01'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2016-04-30'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010;
 use strict;
@@ -55,7 +55,7 @@ App::ListOrgTodos - List all todo items in all Org files
 
 =head1 VERSION
 
-This document describes version 0.41 of App::ListOrgTodos (from Perl distribution App-OrgUtils), released on 2016-04-01.
+This document describes version 0.42 of App::ListOrgTodos (from Perl distribution App-OrgUtils), released on 2016-04-30.
 
 =head1 SYNOPSIS
 
@@ -76,6 +76,15 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<allow_duplicates> => I<bool>
+
+Whether to allow headline to be listed more than once.
+
+This is only relevant when C<group_by_tags> is on. Normally when a headline has
+several tags, it will only be listed under its first tag. But when this option
+is turned on, the headline will be listed under each of its tag (which mean a
+single headline will be listed several times).
+
 =item * B<detail> => I<bool> (default: 0)
 
 Show details instead of just titles.
@@ -110,8 +119,10 @@ Only show headlines having this level as the minimum.
 Whether to group result by tags.
 
 If set to true, instead of returning a list, this function will return a hash of
-lists, keyed by tag: {tag1: [hl1, hl2, ...], tag2: [...]}. Note that some
-headlines might be listed more than once if it has several tags.
+lists, keyed by tag: {tag1: [hl1, hl2, ...], tag2: [...]}. Note that a headline
+that has several tags will only be listed under its first tag, unless when
+C<allow_duplicates> is set to true, in which case the headline will be listed
+under each of its tag.
 
 =item * B<has_tags> => I<array[str]>
 
@@ -200,7 +211,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
 
 =head1 BUGS
 
